* This file produces the tables and figures in "Can Government Intervention Make Firms More Investment-Ready? A Randomized Experiment in the Western Balkans"
* It starts with the master data file created by first running cleanfinaldata.do

*** Set your directory (and make sure it has a subfolder called output in it).
cd "C:\Users\wb200090\Dropbox\WesternBalkans_Startups_Project\Data\PublicUseData\Data"

*** Use the master data file created by cleanfinaldata.do
use "IRMasterData.dta", clear

* Analysis was done in Stata 15.1. Set this version, which can matter for random number generation
version 15.1

* Install Stata add-ons if not installed
ssc install estrat
ssc install coefplot

******************************************************************************************
********* Tables and Figures *************************************************************
******************************************************************************************

****************************************************************************************************
********* Figure 1: Comparing Distributions of Scores at Competition *******************************
****************************************************************************************************
*** Figure 1a: Comparison of baseline scores for those participating in semifinals
cap drop atx aty
kdensity score if treat==1 & agreedscore~=., gen(atx aty)
cap drop atx1 aty1
kdensity score if treat==0 & agreedscore~=., at(atx) gen(atx1 aty1)
sort atx
label var aty "Treatment"
label var aty1 "Control"
label var atx "Baseline score"
twoway line aty aty1 atx, saving( "output\Figure1a.gph", replace) lpattern(l -) ytitle("Proportion of Firms") scheme(s1mono) title("Baseline Scores")
ksmirnov score if attrit==0, by(treat)

** Figure 1b: Comparison of competition scores 
cap drop atx aty
kdensity agreedscore if treat==1, gen(atx aty)
cap drop atx1 aty1
kdensity agreedscore if treat==0, at(atx) gen(atx1 aty1)
sort atx
label var aty "Treatment"
label var aty1 "Control"
label var atx "Semifinals score"
twoway line aty aty1 atx, saving( "output\Figure1b.gph", replace) lpattern(l -) ytitle("Proportion of Firms") scheme(s1mono) title("Competition Scores")
ksmirnov agreedscore, by(treat)

graph combine "output\Figure1a.gph" "output\Figure1b.gph", col(2) scheme(s1mono) saving("output\Figure1.gph", replace)

*******************************************************************************************************
******** Figure 2: Heterogeneity by Firm Size *********************************************************
*******************************************************************************************************

*** Rolling window of approx 30% of sample at a time
gen treatsize1=treat
label var treatsize1 "1-2 workers"
gen treatsize2=treat
label var treatsize2 "2-3 workers"
gen treatsize3=treat
label var treatsize3 "3-4 workers"
gen treatsize4=treat
label var treatsize4 "4-6 workers"
gen treatsize5=treat
label var treatsize5 "6+ workers"


eststo clear
reg agreedscore treatsize1 score croatia serbia private if numberofemployeestoday<=2,  robust
estimates store size1
reg agreedscore treatsize2 score croatia serbia private if numberofemployeestoday>=2 & numberofemployeestoday<=3,  robust
estimates store size2
reg agreedscore treatsize3 score croatia serbia private if numberofemployeestoday>=3 & numberofemployeestoday<=4,  robust
estimates store size3
reg agreedscore treatsize4 score croatia serbia private if numberofemployeestoday>=4 & numberofemployeestoday<=6,  robust
estimates store size4
reg agreedscore treatsize5 score croatia serbia private if numberofemployeestoday>=6 ,  robust
estimates store size5
coefplot (size1, label(1-2 workers) offset(0)) (size2, label(2-3 workers)) (size3, label(3-4 workers)) (size4, label(4-6 workers)) (size5, label(6+ workers)), ///
drop(_cons score croatia serbia privateinvestorfunded) yline(0) vertical legend(off) msymbol(D) mfcolor(white) ciopts(lwidth(*3) lcolor(*.6)) levels(90) ///
ytitle("Treatment Effect") xtitle("Baseline Number of Workers") scheme(s1mono) ///
title("Impact on Investment Readiness Score") saving("output/Figure2a.gph", replace)

eststo clear
reg fu2_f1_external2 treatsize1 score croatia serbia private if numberofemployeestoday<=2,  robust
estimates store size1
reg fu2_f1_external2 treatsize2 score croatia serbia private if numberofemployeestoday>=2 & numberofemployeestoday<=3,  robust
estimates store size2
reg fu2_f1_external2 treatsize3 score croatia serbia private if numberofemployeestoday>=3 & numberofemployeestoday<=4,  robust
estimates store size3
reg fu2_f1_external2 treatsize4 score croatia serbia private if numberofemployeestoday>=4 & numberofemployeestoday<=6,  robust
estimates store size4
reg fu2_f1_external2 treatsize5 score croatia serbia private if numberofemployeestoday>=6 ,  robust
estimates store size5
coefplot (size1, label(1-2 workers) offset(0)) (size2, label(2-3 workers)) (size3, label(3-4 workers)) (size4, label(4-6 workers)) (size5, label(6+ workers)), ///
drop(_cons score croatia serbia privateinvestorfunded) yline(0) vertical legend(off) msymbol(D) mfcolor(white) ciopts(lwidth(*3) lcolor(*.6)) levels(90) ///
ytitle("Treatment Effect") xtitle("Baseline Number of Workers") scheme(s1mono) ///
title("Impact on Making a Deal with an Investor") lstyle(p1 p1 p1 p1 p1) saving("output/Figure2b.gph", replace)

graph combine "output/Figure2a.gph" "output/Figure2b.gph", col(1) scheme(s1mono)
* edited with FigureSizerecorder.grec to get colors same on lines and markers, then saved as Figure2.gph


******************************************************************************************
*** Table 1: Comparison of baseline characteristics and showing baseline balance;  *******
**** also then compare baseline balance for those who participate in the semi-finals *****
******************************************************************************************

mat y = J(25,6,.)	
local k=1
foreach var of varlist croatia serbia score privateinvestor marketattractiveness producttechnology traction team sectorbusproduct sectorlifestyle cloudtech bigdata developer serviceprovider firmage earlystage  whatwereyourrevenuesin2014 numberofemployeestoday age postgradeduc femalefounder globalfocus haveyouacceptedoutsidefunding  haveyouparticipatedinamentoringa {

sum `var' if treat==1
mat y[`k',1] = r(mean)
sum `var' if treat==0
mat y[`k',2] = r(mean)
areg `var' treat, r a(stratabig)
test treat==0
mat y[`k', 3]=r(p)

sum `var' if treat==1 & attrit==0
mat y[`k',4] = r(mean)
sum `var' if treat==0 & attrit==0
mat y[`k',5] = r(mean)
areg `var' treat if attrit==0, r a(stratabig)
test treat==0
mat y[`k', 6]=r(p)

local k=`k'+1
}
count if treat==1
mat y[25,1]=r(N)
count if treat==0
mat y[25,2]=r(N)
count if treat==1 & attrit==0
mat y[25,4]=r(N)
count if treat==0 & attrit==0
mat y[25,5]=r(N)

mat rownames y = croatia serbia score privateinvestor marketattractiveness producttechnology traction team sectorbusproduct sectorlifestyle cloudtech bigdata developer serviceprovider firmage earlystage  whatwereyourrevenuesin2014 numberofemployeestoday age postgradeduc femalefounder globalfocus haveyouacceptedoutsidefunding  haveyouparticipatedinamentoringa     "Sample Size"
mat colnames y = "Treatment" "Control""P-value" "Treatment" "Control" "P-value"
mat2txt, matrix(y) saving("output\Table1paper.xls") replace

* Joint tests of orthogonality shown in last line of table
reg treat croatia serbia score marketattractiveness producttechnology traction team sectorbusproduct sectorlifestyle cloudtech bigdata developer serviceprovider firmage earlystage  numberofemployeestoday age postgradeduc femalefounder globalfocus haveyouacceptedoutsidefunding privateinvestor haveyouparticipatedinamentoringa, r
reg treat croatia serbia score marketattractiveness producttechnology traction team sectorbusproduct sectorlifestyle cloudtech bigdata developer serviceprovider firmage earlystage  numberofemployeestoday age postgradeduc femalefounder globalfocus haveyouacceptedoutsidefunding privateinvestor haveyouparticipatedinamentoringa if attrit==0, r

**************************************************************************************************************
******* Table 2: Impact on Judge's Scores ********************************************************************
**************************************************************************************************************

gen finalist=top50David==1|(rankadjscore<=40 & Present>=3)
eststo clear
* Base specification: controls for randomization strata
local i=1
foreach var of varlist agreedscore Team Technology Traction Market Progress Presentation  finalist sdtotalscore{
areg `var' treat if agreedscore~=., a(stratabig) robust
sum `var' if treat==0
estadd scalar mean=r(mean)
estadd scalar stddev=r(sd)
eststo table2a_`i' 
local i=`i'+1
}
* Robustness specification: also control for judge fixed effects
local i=1
foreach var of varlist agreedscore Team Technology Traction Market Progress Presentation finalist sdtotalscore {
areg `var' treat judge1-judge66 if agreedscore~=., a(stratabig) robust
sum `var' if treat==0
estadd scalar mean=r(mean)
estadd scalar stddev=r(sd)
eststo table2b_`i' 
local i=`i'+1
}
#delimit ;
esttab table2a_* table2b_* using "output\table2.csv", replace depvar legend label nonumbers nogaps
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) drop(_cons judge*)
	stats(N mean stddev, fmt(%9.0g %9.3f ) labels("Sample Size" "Control Mean" "Control Std. Dev")) 
	title("Table 2: Impacts on Investment Readiness") addnotes("""") ;
#delimit cr

*************************************************************************************************************
****** Table 3: Impact on Firm Outcomes *************************************************************
*************************************************************************************************************

eststo clear
areg mediabuzz2016 treat b_mediabuzz2016, a(stratabig) robust
sum mediabuzz2016 if treat==0
estadd scalar mean=r(mean)
estadd scalar stddev=r(sd)
eststo table3a_1
areg mediabuzz2017 treat b_mediabuzz2017, a(stratabig) robust
sum mediabuzz2017 if treat==0
estadd scalar mean=r(mean)
estadd scalar stddev=r(sd)
eststo table3b_1 

cap drop fu2_f1_operate
gen fu2_f1_operate=fu2_operate
local i=2
foreach var of varlist f1_operate f1_interestindex f1_generalindex f1_specificindex f1_stepindex f1_externalindex  f1_external2  {
areg `var' treat, a(stratabig) robust
sum `var' if treat==0
estadd scalar mean=r(mean)
estadd scalar stddev=r(sd)
eststo table3a_`i' 
areg fu2_`var' treat, a(stratabig) robust
sum fu2_`var' if treat==0
estadd scalar mean=r(mean)
estadd scalar stddev=r(sd)
eststo table3b_`i' 

local i=`i'+1
}
#delimit ;
esttab table3a_* table3b_*  using "output\table3.csv", replace depvar legend label nonumbers nogaps
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) drop(_cons)
	stats(N mean stddev, fmt(%9.0g %9.3f ) labels("Sample Size" "Control Mean")) 
	title("Table 3: Treatment Impact on Firm Outcomes") addnotes("""") ;
#delimit cr


*****************************************************************************************
****** Table 4: Are Investment Readiness Scores Predictive of Future Outcomes ***********
*****************************************************************************************

eststo clear
local i=1
foreach var of varlist mediabuzz2016 f1_operate f1_interestindex f1_generalindex f1_specificindex f1_stepindex f1_externalindex  f1_external2 ///
mediabuzz2017 fu2_operate fu2_f1_interestindex fu2_f1_generalindex fu2_f1_specificindex fu2_f1_stepindex fu2_f1_externalindex fu2_f1_external2 {
* Basic regression: score on outcome
reg `var' agreedscore if treat==0, robust
sum `var' if treat==0
estadd scalar mean=r(mean)
estadd scalar stddev=r(sd)
eststo table4_`i' 
* Controlling for country, prior investment,  sector, firm age, founder gender and education, baseline employment
reg `var' agreedscore croatia serbia  privateinvestor sectorbusproduct sectorlifestyle firmage earlystage  numberofemployeestoday age postgradeduc femalefounder globalfocus if treat==0,  robust
eststo table4a_`i' 
local i=`i'+1
}
#delimit ;
esttab table4_* table4a_* using "output\table4.csv", replace depvar legend label nonumbers nogaps
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) drop(_cons)
	stats(N mean stddev, fmt(%9.0g %9.3f ) labels("Sample Size" "Control Mean")) 
	title("Table 4: Correlation of Score with Outcomes in Control Group") addnotes("""") ;
#delimit cr


******************************************************************************************
****** Table 5: Heterogeneous Treatment Effects by Firm Size *****************************
******************************************************************************************

*** Heterogeneity by firm size
sum numberofemployeestoday, de
cap drop abovemedsize treat_abovemedsize
gen abovemedsize=cond(numberofemployeestoday>=4,1,0)
gen treat_abovemedsize=abovemedsize*treat

eststo clear
local i=1
foreach var of varlist agreedscore mediabuzz2017 fu2_operate fu2_f1_interestindex fu2_f1_generalindex fu2_f1_specificindex fu2_f1_stepindex fu2_f1_externalindex fu2_f1_external2 {
areg `var' treat treat_abovemedsize abovemedsize, a(stratabig) robust
sum `var' if treat==0 & abovemedsize==0
estadd scalar mean1=r(mean)
sum `var' if treat==0 & abovemedsize==1
estadd scalar mean2=r(mean)
eststo table5_`i' 
local i=`i'+1
}
#delimit ;
esttab table5_* using "output\table5.csv", replace depvar legend label nonumbers nogaps
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) drop(_cons)
	stats(N mean1 mean2, fmt(%9.0g %9.3f ) labels("Sample Size" "Control Mean Small Firms" "Control Mean Larger Firms")) 
	title("Table 5: Heterogeneity in Impacts by Initial Firm Size") addnotes("""") ;
#delimit cr

******************************************************************************************************
* Table 6: Heterogeneous Treatment Effects by Predicted Likelihood of Making a Deal with an Investor *
******************************************************************************************************

set seed 124
estrat fu2_f1_external2 treat abovemedsize score croatia serbia privateinvestor earlystage sectorbusproduct sectorlifestyle  firmage postgrad globalfocus femalefounder haveyouparticipatedinamentoringa, groups(2) savegroup reps(200) boot(500)


matrix b=e(LOO_C)
matrix bse=e(LOO_SE)

matrix c=e(RSS_C)
matrix cse=e(RSS_SE)

mat y = J(4,2,.)	
mat y[1,1] = b[1,1]
mat y[2,1] = bse[1,1]
mat y[3,1] = b[1,2]
mat y[4,1] = bse[1,2]

mat y[1,2] = c[1,1]
mat y[2,2] = cse[1,1]
mat y[3,2] = c[1,2]
mat y[4,2] = cse[1,2]

mat2txt, matrix(y) saving("output\Table6.xls") replace

*** Generate indicator of low predicted likelihood of funding for use in Appendix Table 10
gen lowpredprob=cond(estrat_loo_group==1,1,0)


**********************************************************************************************************************************
**********************************************************************************************************************************
************************  ONLINE APPENDICES **************************************************************************************
**********************************************************************************************************************************
**********************************************************************************************************************************

**************************************************************************
***** Appendix Table A6.1 - Judge Characteristics *************************
**************************************************************************
preserve
use "JudgeData.dta", clear

gen balkans=country=="Kosovo"|country=="Serbia"|country=="Croatia"|country=="Macedonia"|country=="Montenegro"
gen EUeurope=country=="Austria"|country=="Germany"|country=="Bulagria"|country=="Bulgaria"|country=="Greece"|country=="Czech Republic"|country=="Italy"|country=="Netherlands"|country=="Poland"|country=="Slovenia"|country=="United Kingdom"
gen male=gender=="m"
destring age, force replace
gen foundedcompany=haveyoufoundedacompanyinthepast=="Yes, exactly one"|haveyoufoundedacompanyinthepast=="Yes, more than one"
gen yearsindustryexperience=howmanyyearsofexperiencedoyouhav
gen ventureinvestor=1
replace ventureinvestor=. if howmanyventurecapitalinvestments=="n.a."
replace ventureinvestor=0 if howmanyventurecapitalinvestments=="None"
gen angelinvestor=cond(areyouanangelinvestor=="Yes",1,0) if areyouanangelinvestor~="n.a."
gen mentor=1
replace mentor=0 if areyouaregularmentortostartupent=="No, not at the moment"
replace mentor=. if areyouaregularmentortostartupent=="n.a."
mat y = J(10,2,.)	
local k=1
foreach var of varlist balkans EUeurope male age foundedcompany yearsindustryexperience ventureinvestor angelinvestor mentor {

sum `var'
mat y[`k',1] = r(mean)
mat y[`k',2] = r(sd)
local k=`k'+1
}
count 
mat y[10,1]=r(N)


mat rownames y = balkans EUeurope male age foundedcompany yearsindustryexperience ventureinvestor angelinvestor mentor     "Sample Size"
mat colnames y = "Mean" "Std. Dev."
mat2txt, matrix(y) saving("output\Tablea6_1.xls") replace
restore

********************************************************************************************************
***** Appendix Figure A6.1: Baseline IR by participation in Semi-Finals *********************************
********************************************************************************************************
*Comparing Distributions of Scores by Participation or Not and Treatment Status
gen participatesemis=attrit==0
cap drop atx aty
kdensity score if treat==1 & participatesemis==1, gen(atx aty)
cap drop atxa atya
kdensity score if treat==1 & participatesemis==0, at(atx) gen(atxa atya)
cap drop atx1 aty1
kdensity score if treat==0 & participatesemis==1, at(atx) gen(atx1 aty1)
cap drop atx1a aty1a
kdensity score if treat==0 & participatesemis==0, at(atx) gen(atx1a aty1a)
sort atx
label var aty "Treatment Attend"
label var aty1 "Control Attend"
label var atya "Treatment Don't Attend"
label var aty1a "Control Don't Attend"
label var atx "Semifinals score"
twoway line aty atya aty1 aty1a atx, saving( "output\FigureA6_1.gph", replace) lpattern(l - _ -..-) ytitle("Proportion of Firms") scheme(s1mono)


************************************************************************************************************
***** Appendix Table A6.2: Robustness of Impact on IR scores to attrition and weighting *********************
************************************************************************************************************
***************** Robustness of Investment Readiness Results to Attrition (Not participating in Semi-Finals)

*** Imputed Score for those not attending
*** Based on Pre-specified imputation
reg agreedscore  team marketattractiveness producttechnology traction croatia serbia privateinvestor if treat==0
predict fittedscore
gen imputedscore=agreedscore
replace imputedscore=fittedscore if agreedscore==.

*** Lee bounds: 4.6% higher attrition for control group: trim 4.6% of 174 = 8 people from treated group = 7.3%
set seed 124
egen rank1o=rank(agreedscore), by(treat) unique
gen leescoreu=agreedscore
replace leescoreu=. if treat==1 & rank1o<=8
gen leescorel=agreedscore
replace leescorel=. if treat==1 & rank1o>102

*** Robustness to alternative weighting of scores
* Equal weighting of 5 components
gen equal5=0.2*Team+0.2*Technology+0.2*Traction+0.2*Market+0.2*Progress
gen equal6=(Team+Technology+Traction+Market+Progress+Presentation)/6


eststo clear
local i=1
foreach var of varlist agreedscore imputedscore leescoreu leescorel equal5 equal6 {
areg `var' treat, a(stratabig) robust
sum `var' if treat==0
estadd scalar mean=r(mean)
estadd scalar stddev=r(sd)
eststo tableapp4_`i' 
local i=`i'+1
}

#delimit ;
esttab tableapp4_* using output\tablea6_2.csv, replace depvar legend label nonumbers nogaps
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) drop(_cons)
	stats(N mean stddev, fmt(%9.0g %9.3f ) labels("Sample Size" "Control Mean" "Control Std. Dev")) 
	title("Appendix Table 6.2: Robustness of Impact on Investment Readiness to Attrition") addnotes("""") ;
#delimit cr


*******************************************************************************************************
*** Table A6.3: Heterogeneity in Impact by Baseline IR level *********************************************
*******************************************************************************************************
*** Pre-specified heterogeneity in outcome by baseline investment readiness
gen lowready=score<3
gen treat_lowready=treat*lowready

eststo clear
* Base specification: controls for randomization strata
local i=1
foreach var of varlist agreedscore  Presentation sdtotalscore {
areg `var' treat treat_lowready lowready if agreedscore~=., a(stratabig) robust
sum `var' if treat==0
estadd scalar mean=r(mean)
estadd scalar stddev=r(sd)
eststo tablea6_3_`i' 
local i=`i'+1
}
#delimit ;
esttab tablea6_3_* using "output\tablea6_3.csv", replace depvar legend label nonumbers nogaps
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) drop(_cons)
	stats(N mean stddev, fmt(%9.0g %9.3f ) labels("Sample Size" "Control Mean" "Control Std. Dev")) 
	title("Table 6.3: Heterogeneity in Impacts on Investment Readiness") addnotes("""") ;
#delimit cr

****************************************************************************
***** Table A6.4: Quantile Treatment Analysis suggested by referee 2 ********
****************************************************************************

eststo clear
qreg agreedscore treat croatia serbia score privateinvestor, q(0.1)
eststo qtab_1
qreg agreedscore treat croatia serbia score privateinvestor, q(0.25)
eststo qtab_2
qreg agreedscore treat croatia serbia score privateinvestor, q(0.5)
eststo qtab_3
qreg agreedscore treat croatia serbia score privateinvestor, q(0.75)
eststo qtab_4
qreg agreedscore treat croatia serbia score privateinvestor, q(0.9)
eststo qtab_5
#delimit ;
esttab qtab_* using "output\Tablea6_4.csv", replace depvar legend label nonumbers nogaps
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) 
	stats(N pval, fmt(%9.0g %9.3f ) labels("Sample Size" "P-value")) 
	title("Quantile Treatment Effects on Investment Readiness Score") addnotes("""") ;
#delimit cr

***************************************************************************************************
****** Appendix Table A6.5 *************************************************************************
***************************************************************************************************
* are poorer quality firms likely to exit quickly in treatment?
gen score_treat=score*treat
gen agreedscore_treat=agreedscore*treat

eststo clear
probit f1_operate score score_treat treat, r
margins, dydx(*) post
eststo TableA6_5_1
probit fu2_operate score score_treat treat, r
margins, dydx(*) post
eststo TableA6_5_2
probit f1_operate agreedscore agreedscore_treat treat, r
margins, dydx(*) post
eststo TableA6_5_3
probit fu2_operate agreedscore agreedscore_treat treat, r
margins, dydx(*) post
eststo TableA6_5_4
probit fu2_f1_external2 score score_treat treat, r
margins, dydx(*) post
eststo TableA6_5_5
probit fu2_f1_external2 agreedscore agreedscore_treat treat, r
margins, dydx(*) post
eststo TableA6_5_6

#delimit ;
esttab TableA6_5_* using "output\tableA6_5.csv", replace depvar legend label nonumbers nogaps
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) 
	stats(N pval, fmt(%9.0g %9.3f ) labels("Sample Size" "P-value")) 
	title("Appendix Table 6.5: Heterogeneity in Impacts by Quality") addnotes("""") ;
#delimit cr


*********************************************************************************************
**** Appendix Table A7: Comparison of Pioneers of The Balkans Firms to Other Beneficiaries ***
*********************************************************************************************

*** Column 2 directly supplied by Serbian Innovation Agency, raw data not available
keep if firmid~=.
* construct variables used in summary table
gen emp1=cond(numberofemployeestoday==1,100,0)
gen emp2=cond(numberofemployeestoday==2,100,0)
gen emp3=cond(numberofemployeestoday==3,100,0)
gen emp4=cond(numberofemployeestoday>=4 & numberofemployeestoday<=6,100,0)
gen emp5=cond(numberofemployeestoday>=7 & numberofemployeestoday<=10,100,0)
gen emp6=cond(numberofemployeestoday>10,100,0)

gen age1=cond(firmage<=1,100,0)
gen age2=cond(firmage==2,100,0)
gen age3=cond(firmage==3,100,0)
gen age4=cond(firmage==4,100,0)
gen age5=cond(firmage==5,100,0)

gen fem1=cond(femalefounder==1,100,0)
gen educ1=cond(postgradeduc==1,100,0) 
gen rev1=cond(whatwereyourrevenuesin2014==0,100,0)
gen fund1=cond(privateinvestor==1,100,0)

gen sec1=cond(sectorbusproduct==1,100,0)
gen sec2=cond(sectorlifestyle==1,100,0)
gen sec3=cond(yoursector=="Materials & Manufacturing",100,0)

mat y = J(20,1,.)
local k=1
foreach var of varlist emp1 emp2 emp3 emp4 emp5 emp6 {
sum `var'
mat y[`k',1] = r(mean)
local k=`k'+1
}
local k=8
foreach var of varlist age1 age2 age3 age4 age5 fem1 educ1 rev1 fund1 {
sum `var'
mat y[`k',1] = r(mean)
local k=`k'+1
}
local k=18
foreach var of varlist sec1 sec2 sec3 {
sum `var'
mat y[`k',1] = r(mean)
local k=`k'+1
}

mat rownames y = "1" "2" "3" "4 to 6" "7 to 10" "11+" " " "1 year or less" "2" "3" "4" "5+ years" "At least one female founder" "post-graduate education" "Made no revenue" "received investor funding" " " "Business and Productivity" "Lifestyle and Entertainment" "Materials and Manufacturing"
mat colnames y = "% of Firms" 
mat2txt, matrix(y) saving("output\Tablea7.xls") replace



******************************************************************************************************
***** Appendix Table A8.1: Survey completion rates by treatment status              *******************
******************************************************************************************************
mat y = J(7,4,.)	
local k=1
foreach var of varlist follow1 follow2 follow3 fu2_follow1 fu2_follow2 fu2_follow3 {
sum `var' 
mat y[`k',1] = r(mean)
sum `var' if treat==1
mat y[`k',2] = r(mean)
sum `var' if treat==0
mat y[`k',3] = r(mean)
areg `var' treat, r a(stratabig)
test treat==0
mat y[`k', 4]=r(p)
local k=`k'+1
}
count 
mat y[7,1]=r(N)
count if treat==1
mat y[7,2]=r(N)
count if treat==0
mat y[7,3]=r(N)

mat rownames y = "Full Survey" "At least Short" "At least Basic"  "In 2017 Full" "In 2017 partial" "In 2017 Basic"   "Sample Size"
mat colnames y = "Overall" "Treatment" "Control""P-value" 
mat2txt, matrix(y) saving("output\Tablea8_1paper.xls") replace

***********************************************************************************************
*** Appendix Table A8.2: Baseline balance for those who answer surveys  ************************
***********************************************************************************************

mat y = J(25,6,.)	
local k=1
foreach var of varlist croatia serbia score privateinvestor marketattractiveness producttechnology traction team sectorbusproduct sectorlifestyle cloudtech bigdata developer serviceprovider firmage earlystage  whatwereyourrevenuesin2014 numberofemployeestoday age postgradeduc femalefounder globalfocus haveyouacceptedoutsidefunding  haveyouparticipatedinamentoringa {

sum `var' if treat==1 & follow2==1
mat y[`k',1] = r(mean)
sum `var' if treat==0 & follow2==1
mat y[`k',2] = r(mean)
areg `var' treat if follow2==1, r a(stratabig)
test treat==0
mat y[`k', 3]=r(p)

sum `var' if treat==1 & fu2_follow2==1
mat y[`k',4] = r(mean)
sum `var' if treat==0 & fu2_follow2==1
mat y[`k',5] = r(mean)
areg `var' treat if fu2_follow2==1, r a(stratabig)
test treat==0
mat y[`k', 6]=r(p)

local k=`k'+1
}
count if treat==1 & follow2==1
mat y[25,1]=r(N)
count if treat==0 & follow2==1
mat y[25,2]=r(N)
count if treat==1 & fu2_follow2==1
mat y[25,4]=r(N)
count if treat==0 & fu2_follow2==1
mat y[25,5]=r(N)

mat rownames y = croatia serbia score privateinvestor marketattractiveness producttechnology traction team sectorbusproduct sectorlifestyle cloudtech bigdata developer serviceprovider firmage earlystage  whatwereyourrevenuesin2014 numberofemployeestoday age postgradeduc femalefounder globalfocus haveyouacceptedoutsidefunding  haveyouparticipatedinamentoringa     "Sample Size"
mat colnames y = "Treatment" "Control""P-value" "Treatment" "Control" "P-value"
mat2txt, matrix(y) saving("output\TableA8_2.xls") replace

* Joint test of orthogonality
reg treat croatia serbia score marketattractiveness producttechnology traction team sectorbusproduct sectorlifestyle cloudtech bigdata developer serviceprovider firmage earlystage  numberofemployeestoday age postgradeduc femalefounder globalfocus haveyouacceptedoutsidefunding privateinvestor haveyouparticipatedinamentoringa if follow2==1, r
reg treat croatia serbia score marketattractiveness producttechnology traction team sectorbusproduct sectorlifestyle cloudtech bigdata developer serviceprovider firmage earlystage  numberofemployeestoday age postgradeduc femalefounder globalfocus haveyouacceptedoutsidefunding privateinvestor haveyouparticipatedinamentoringa if fu2_follow2==1, r




*************************************************************************************************************
****** Appendix Table A9.0: Impact on Components of Media Buzz Index  ***************************************
*************************************************************************************************************
eststo clear
local i=1
foreach var of varlist anymedia m1_totalnumber_trim Facebooktrim twitter2016_trim mediabuzz2016 anymedia2017 m2_totalnumber_trim facebooktrim twitter2017_trim mediabuzz2017 {
areg `var' treat b_`var', a(stratabig) robust
sum `var' if treat==0
estadd scalar mean=r(mean)
estadd scalar stddev=r(sd)
eststo tablesm_`i' 
local i=`i'+1
}

#delimit ;
esttab tablesm_*  using "output\tablea9_0.csv", replace depvar legend label nonumbers nogaps
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) drop(_cons)
	stats(N mean stddev, fmt(%9.0g %9.3f ) labels("Sample Size" "Control Mean")) 
	title("Appendix Table 9.0: Impacts on Components of Media Buzz Index") addnotes("""") ;
#delimit cr

**********************************************************************************************************
**** Appendix Tables A9.1 to A9.5: Impacts on Individual Outcomes     **************************************
**********************************************************************************************************

*********************************************************************
**** Domain 2: Investment Readiness ********************************
*********************************************************************

********* Appendix Table A9.1 **********************************************************
** 2a: willingness and interest in taking on equity investment
eststo clear
local i=1
foreach var of varlist f1_interest1 f1_interest2 f1_interest3 f1_interest4 f1_interestindex {
areg `var' treat, a(stratabig) robust
sum `var' if treat==0
estadd scalar mean=r(mean)
estadd scalar stddev=r(sd)
eststo tablef4_`i' 
areg fu2_`var' treat, a(stratabig) robust
sum fu2_`var' if treat==0
estadd scalar mean=r(mean)
estadd scalar stddev=r(sd)
eststo tablef4a_`i' 
local i=`i'+1
}
#delimit ;
esttab tablef4_*  tablef4a_* using "output\tablea9_1.csv", replace depvar legend label nonumbers nogaps
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) drop(_cons)
	stats(N mean stddev, fmt(%9.0g %9.3f ) labels("Sample Size" "Control Mean")) 
	title("Appendix Table 9.1: Impacts on Investment Readiness") addnotes("""") ;
#delimit cr

*********** Appendix Table A9.2 **************************************************************
*** 2B: General Investability
eststo clear
local i=1
foreach var of varlist f1_general1 f1_general2 f1_general3 f1_general4 f1_general5 f1_general6 f1_generalindex {
areg `var' treat, a(stratabig) robust
sum `var' if treat==0
estadd scalar mean=r(mean)
estadd scalar stddev=r(sd)
eststo tablef5_`i' 
areg fu2_`var' treat, a(stratabig) robust
sum fu2_`var' if treat==0
estadd scalar mean=r(mean)
estadd scalar stddev=r(sd)
eststo tablef5a_`i' 
local i=`i'+1
}
#delimit ;
esttab tablef5_* tablef5a_* using "output\tablea9_2.csv", replace depvar legend label nonumbers nogaps
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) drop(_cons)
	stats(N mean stddev, fmt(%9.0g %9.3f ) labels("Sample Size" "Control Mean")) 
	title("Appendix Table 9.2: Impacts on General Investability") addnotes("""") ;
#delimit cr

************ Appendix Table A9.3 ************************************************************************
*** 2C: meeting the specific needs of investors
eststo clear
local i=1
foreach var of varlist f1_specific1 f1_specific2 f1_specific3 f1_specific4 f1_specific5 f1_specific6 f1_specificindex {
areg `var' treat, a(stratabig) robust
sum `var' if treat==0
estadd scalar mean=r(mean)
estadd scalar stddev=r(sd)
eststo tablef6_`i' 
areg fu2_`var' treat, a(stratabig) robust
sum fu2_`var' if treat==0
estadd scalar mean=r(mean)
estadd scalar stddev=r(sd)
eststo tablef6a_`i' 
local i=`i'+1
}
#delimit ;
esttab tablef6_* tablef6a_* using "output\tablea9_3.csv", replace depvar legend label nonumbers nogaps
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) drop(_cons)
	stats(N mean stddev, fmt(%9.0g %9.3f ) labels("Sample Size" "Control Mean")) 
	title("Appendix Table 9.3: Impacts on Specific Needs of Investors") addnotes("""") ;
#delimit cr

*****************************************************************************************************
**** Domain 3: Steps Towards Getting External Financing and Financing Received ********************************
***************************************************************************************************
****** Appendix Table A9.4 ************************************************************************
*** 3A: Steps towards getting external financing
eststo clear
local i=1
foreach var of varlist f1_step1 f1_step2 f1_step3 f1_step4  f1_stepindex {
areg `var' treat, a(stratabig) robust
sum `var' if treat==0
estadd scalar mean=r(mean)
estadd scalar stddev=r(sd)
eststo tablef7_`i' 
areg fu2_`var' treat, a(stratabig) robust
sum fu2_`var' if treat==0
estadd scalar mean=r(mean)
estadd scalar stddev=r(sd)
eststo tablef7a_`i' 
local i=`i'+1
}

#delimit ;
esttab tablef7_* tablef7a_* using "output\tablea9_4.csv", replace depvar legend label nonumbers nogaps
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) drop(_cons)
	stats(N mean stddev, fmt(%9.0g %9.3f ) labels("Sample Size" "Control Mean")) 
	title("Appendix Table 9.4: Impacts on Steps Towards Investment") addnotes("""") ;
#delimit cr

********** Appendix Table A9.5 *******************************************************************
*** 3B: External Financing Received
eststo clear
local i=1
foreach var of varlist f1_external1 f1_external2 f1_external3  f1_external5 f1_externalindex {
areg `var' treat, a(stratabig) robust
sum `var' if treat==0
estadd scalar mean=r(mean)
estadd scalar stddev=r(sd)
eststo tablef8_`i' 
areg fu2_`var' treat, a(stratabig) robust
sum fu2_`var' if treat==0
estadd scalar mean=r(mean)
estadd scalar stddev=r(sd)
eststo tablef8a_`i' 
local i=`i'+1
}
#delimit ;
esttab tablef8_* tablef8a_* using "output\tablea9_5.csv", replace depvar legend label nonumbers nogaps
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) drop(_cons)
	stats(N mean stddev, fmt(%9.0g %9.3f ) labels("Sample Size" "Control Mean")) 
	title("Appendix Table 9.5: Impacts on External Investment") addnotes("""") ;
#delimit cr

***************************************************************************************************************
************* Appendix Table A10: Comparison of Low and High Likelihood Firms on Baseline Characteristics **************
***************************************************************************************************************
gen lowlikelihood=cond(estrat_loo_group==1,1,0)
mat y = J(25,3,.)	
local k=1
foreach var of varlist croatia serbia score privateinvestor marketattractiveness producttechnology traction team sectorbusproduct sectorlifestyle cloudtech bigdata developer serviceprovider firmage earlystage  whatwereyourrevenuesin2014 numberofemployeestoday age postgradeduc femalefounder globalfocus haveyouacceptedoutsidefunding  haveyouparticipatedinamentoringa {

sum `var' if estrat_loo_group==1
mat y[`k',1] = r(mean)
sum `var' if estrat_loo_group==2
mat y[`k',2] = r(mean)
areg `var' lowlikelihood, r a(stratabig)
test lowlikelihood==0
mat y[`k', 3]=r(p)

local k=`k'+1
}
count if estrat_loo_group==1
mat y[25,1]=r(N)
count if estrat_loo_group==2
mat y[25,2]=r(N)

mat rownames y = croatia serbia score privateinvestor marketattractiveness producttechnology traction team sectorbusproduct sectorlifestyle cloudtech bigdata developer serviceprovider firmage earlystage  whatwereyourrevenuesin2014 numberofemployeestoday age postgradeduc femalefounder globalfocus haveyouacceptedoutsidefunding  haveyouparticipatedinamentoringa     "Sample Size"
mat colnames y = "1-3 Workers" "4+ Workers""P-value" 
mat2txt, matrix(y) saving("output\TableA10.xls") replace



