***** This file merges together all the different datasets, and then creates the different variables used for analysis

* Set Directory - and make sure you have a subfolder named "output" in this directory
cd "C:\Users\wb200090\Dropbox\WesternBalkans_Startups_Project\Data\PublicUseData\Data"

**** Merge Different Datasets Together

* Start with Baseline (Application data)
use "IRmasterfile.dta", clear
cap drop _merge
sort firmid
* Merge in First Follow-up Survey
merge firmid using "Follow-up survey Stata Dataset_final1.dta", sort
cap drop _merge
sort firmid
merge firmid using "keymetrics.dta", sort
tab _merge
drop _merge
* merge in meltwater data
sort firmid
merge firmid using "MeltwaterFollowupData.dta"
tab _merge
drop _merge
sort firmid
merge firmid using "Meltwater2017data.dta"
tab _merge
drop _merge
* merge in social media data
sort firmid
merge firmid using "SocialMediaData2016.dta"
tab _merge
drop _merge
sort firmid
merge firmid using "SocialMediaData2017.dta"
tab _merge
drop _merge
* merge in second follow-up data 

sort firmid
merge firmid using "Second_FollowUp_PublicUse.dta", sort
drop _merge

***************************************************************************************************************************************************************************
*********** Construct Master Dataset with Variables Needed for Analysis  **************************************************************************************************
***************************************************************************************************************************************************************************

*********************************************************************
*** Construct Outcome Variables from First Follow-up ****************
*********************************************************************

******* Survey Attrition *************
* Different measures of survey completion
* Fully surveyed by Pioneers
gen follow1=formid~="" & formid~="Short" & formid~="Basic Info"
* Done by Ernest with Short survey or Pioneers
gen follow2=follow1
replace follow2=1 if formid=="Short"
* At least have some very basic 4 question information
gen follow3=follow2
replace follow3=1 if formid=="Basic Info"

*** Domain 1: Business Operation ************
gen f1_operate=1 if coded_werethereanymajoreventsfor<=4
replace f1_operate=0 if coded_werethereanymajoreventsfor==5|coded_werethereanymajoreventsfor==6
label var f1_operate "Operating at time of first follow-up"

*** Domain 2: Investment Readiness **********
*** 2A: Willingness and interest in taking on equity investment ***
gen f1_interest1=areyouinterestedinreceivingneweq==1
replace f1_interest1=. if areyouinterestedinreceivingneweq==.
label var f1_interest1 "Interested in receiving equity investment"
gen f1_interest2=whatisthemaximumshareofequityiny
* replace max share as 0 if not interested
replace f1_interest2=0 if f1_interest2==. & f1_interest1==0
label var f1_interest2 "Maximum share of equity would sell"
gen f1_interest3=doyouhavespecificdealtermstooffe==1
replace f1_interest3=. if doyouhavespecificdealtermstooffe==.
replace f1_interest3=0 if f1_interest3==. & f1_interest1==0
label var f1_interest3 "Has specific deal terms to offer investor"
gen f1_interest4=wouldyouconsideraroyaltybasedinv==1
replace f1_interest4=. if wouldyouconsideraroyaltybasedinv==.
label var f1_interest4 "Would consider royalties"

* replace these variables as zero for firms closed down or sold
foreach var of varlist f1_interest1 f1_interest2 f1_interest3 f1_interest4 {
replace `var'=0 if f1_operate==0
}

*** Get z-scores and average
foreach var of varlist f1_interest1 f1_interest2 f1_interest3 f1_interest4   {
  sum `var' 
  local thismean = r(mean) 
  local thissd = r(sd) 
  di "`thismean'" 
  di "`thissd'" 
  cap drop z1_`var'
  gen z1_`var' = (`var'-`thismean')/(`thissd') 
  } 
egen f1_interestindex=rowmean(z1_f1_interest1 z1_f1_interest2 z1_f1_interest3 z1_f1_interest4)
label var f1_interestindex "Aggregate Index of Willingness and Interest in Equity"

*** 2B: General Investability ************
gen f1_general1=howmanypeoplecurrentlyworkinyour
replace f1_general1=0 if f1_operate==0 & f1_general1==.
replace f1_general1=0 if coded_werethereanymajoreventsfor==6
label var f1_general1 "Number of Employees"
gen notfull=substr(doesyourfounderdoyourcofoundersw,1,2)
gen f1_general2=notfull=="Pa"|notfull=="Ye"
replace f1_general2=. if doesyourfounderdoyourcofoundersw==""
replace f1_general2=0 if f1_operate==0 & f1_general2==.
label var f1_general2 "Founders work full-time in business"
gen f1_general3=1 if whatwereyourtotalsalesorrevenues>0 & whatwereyourtotalsalesorrevenues~=.
replace f1_general3=0 if whatwereyourtotalsalesorrevenues==0
replace f1_general3=1 if f1_general3==. & pleasealsoindicatetherevenuerang~="" & pleasealsoindicatetherevenuerang~="0" & pleasealsoindicatetherevenuerang~="0 Euro"
replace f1_general3=0 if pleasealsoindicatetherevenuerang=="0"|pleasealsoindicatetherevenuerang=="0 Euro"
replace f1_general3=0 if f1_operate==0
label var f1_general3 "Has positive revenue"
gen f1_general4=0 if f1_general3==0
replace f1_general4=1 if whatwereyourtotalsalesorrevenues>=10000 & whatwereyourtotalsalesorrevenues~=.
replace f1_general4=0 if whatwereyourtotalsalesorrevenues<10000
replace f1_general4=1 if pleasealsoindicatetherevenuerang~="" & pleasealsoindicatetherevenuerang~="0" & pleasealsoindicatetherevenuerang~="0 Euro" & pleasealsoindicatetherevenuerang~="<10,000 Euro" & pleasealsoindicatetherevenuerang~="<10,000 Euros"
replace f1_general4=0 if pleasealsoindicatetherevenuerang=="0"|pleasealsoindicatetherevenuerang=="0 Euro"|pleasealsoindicatetherevenuerang=="<10,000 Euro"|pleasealsoindicatetherevenuerang=="<10,000 Euros"
label var f1_general4 "Has revenues of at least 10,000 Euros"
gen f1_general5=1 if whatwasthetotaloperatingprofitof>0 & whatwasthetotaloperatingprofitof~=.
replace f1_general5=0  if whatwasthetotaloperatingprofitof<=0
replace f1_general5=0 if pleasealsoindicatetheprofitrange=="business broke-even (0 profit)"|pleasealsoindicatetheprofitrange=="Business made a loss"|pleasealsoindicatetheprofitrange=="0 Euro, business broke-even"|pleasealsoindicatetheprofitrange=="0"
replace f1_general5=0 if f1_general5==. & pleasealsoindicatetheprofitrange~=""
replace f1_general5=0 if f1_operate==0
label var f1_general5 "Made a positive profit"
gen f1_general6=1 if whichmarkets_eu==1|whichmarkets_usa==1
replace f1_general6=0 if whichmarkets_eu==0 & whichmarkets_usa==0
replace f1_general6=0 if f1_operate==0
label var f1_general6 "Made sales to Western Europe or US"

*** Get z-scores and average
foreach var of varlist f1_general1 f1_general2 f1_general3 f1_general4 f1_general5 f1_general6  {
  sum `var' 
  local thismean = r(mean) 
  local thissd = r(sd) 
  di "`thismean'" 
  di "`thissd'" 
  cap drop z1_`var'
  gen z1_`var' = (`var'-`thismean')/(`thissd') 
  } 
egen f1_generalindex=rowmean(z1_f1_general1 z1_f1_general2 z1_f1_general3 z1_f1_general4 z1_f1_general5 z1_f1_general6)
label var f1_generalindex "Aggregate Index of General Investability"
replace f1_generalindex=. if f1_general2==. & f1_general3==. & f1_general4==.

*** 2C: Meeting the specific needs of investors *****
gen f1_specific1=1 if aretheaccountsofthebusinesssepar==1
replace f1_specific1=0 if aretheaccountsofthebusinesssepar==0
replace f1_specific1=0 if f1_operate==0
label var f1_specific1 "Separate business and personal accounts"
gen f1_specific2=1 if doyouhaveinplacerevenueprojectio==1
replace f1_specific2=0 if doyouhaveinplacerevenueprojectio==0|doyouhaveinplacerevenueprojectio==2
replace f1_specific2=0 if f1_operate==0
label var f1_specific2 "Has revenue projection"
gen f1_specific3=1 if doyouknowhowmuchitcoststoacquire==1
replace f1_specific3=0 if doyouknowhowmuchitcoststoacquire==0
replace f1_specific3=0 if f1_operate==0
label var f1_specific3 "Knows customer acquisition cost"
gen f1_specific4=keymetrics
replace f1_specific4=. if f1_specific1==. & f1_specific2==. & f1_specific3==.
label var f1_specific4 "Number of key metrics tracked"
gen f1_specific5=haveyoufoundoutwhetheryourproduc
replace f1_specific5=0 if f1_operate==0 & f1_specific5==.
label var f1_specific5 "Found out intellectual property"
gen f1_specific6=1 if copyright==1|copyright==2|trademark==1|trademark==2|industrialdes==1|industrialdes==2|patent==1|patent==2|other==1|other==2
replace f1_specific6=0 if f1_specific6==. & copyright~=.
replace f1_specific6=0 if f1_specific5==0 & f1_specific6==.
replace f1_specific6=0 if f1_specific6==. & f1_operate==0
label var f1_specific6 "Has IP protection"

*** Get z-scores and average
foreach var of varlist f1_specific1 f1_specific2 f1_specific3 f1_specific4 f1_specific5 f1_specific6  {
  sum `var' 
  local thismean = r(mean) 
  local thissd = r(sd) 
  di "`thismean'" 
  di "`thissd'" 
  cap drop z1_`var'
  gen z1_`var' = (`var'-`thismean')/(`thissd') 
  } 
egen f1_specificindex=rowmean(z1_f1_specific1 z1_f1_specific2 z1_f1_specific3 z1_f1_specific4 z1_f1_specific5 z1_f1_specific6)
label var f1_specificindex "Aggregate Index of specific Investability"


*** Domain 3: Steps towards receiving external funding and external finance received *****
*** 3A: steps towards receiving external financing ***********
gen f1_step1=sinceaugust2015whichhaveyoudonec==1
replace f1_step1=. if sinceaugust2015whichhaveyoudonec==.
replace f1_step1=0 if f1_operate==0 & f1_step1==.
label var f1_step1 "Contacted outside investor"
gen f1_step2=madepitch_noncompetitive==1|madepitch_competitive==1|madepitch_outsideinvestor==1
replace f1_step2=. if madepitch_noncompetitive==. & madepitch_competitive==. & madepitch_outsideinvestor==.
replace f1_step2=0 if f1_operate==0 & f1_step2==.
label var f1_step2 "Made a pitch"
gen f1_step3=haveyouhadamentorandorexternalex
replace f1_step3=0 if f1_operate==0 & f1_step3==.
label var f1_step3 "Has mentor helping"
gen f1_step4=sinceaugust2015haveyouenteredint
replace f1_step4=0 if f1_step4==. & f1_operate==0
label var f1_step4 "Entered into negotiation"

foreach var of varlist f1_step1 f1_step2 f1_step3 f1_step4  {
  sum `var' 
  local thismean = r(mean) 
  local thissd = r(sd) 
  di "`thismean'" 
  di "`thissd'" 
  cap drop z1_`var'
  gen z1_`var' = (`var'-`thismean')/(`thissd') 
  } 
egen f1_stepindex=rowmean(z1_f1_step1 z1_f1_step2 z1_f1_step3 z1_f1_step4)
label var f1_stepindex "Aggregate Index of steps to external finance"
replace f1_stepindex=. if f1_step1==. & f1_step2==. & f1_step3==.

*** 3B: external financing received
gen f1_external1= 1 if whatisthetotalamountofnewdebtyou>0 & whatisthetotalamountofnewdebtyou~=.
replace f1_external1=0 if whatisthetotalamountofnewdebtyou==0
replace f1_external1=0 if pleasealsoindicatetherange=="0"
replace f1_external1=1 if pleasealsoindicatetherange~="0" & pleasealsoindicatetherange~=""
replace f1_external1=0 if doesyourfirmcurrentlyhaveanydebt==0 & f1_external1==.
replace f1_external1=0 if f1_external1==. & f1_operate==0
replace f1_external1=1 if ((newdebtorloan>0 & newdebtorloan~=.)|(newdebtloan_creditcard>0 & newdebtloan_creditcard~=.)|(newdebtloan_personalloan>0 & newdebtloan_personalloan~=.)|(newdebtloan_businessloan>0 & newdebtloan_businessloan~=.)) & f1_external1==.
label var f1_external1 "Taken on new debt"
gen f1_external2=1 if whatwastheoutcomeofthesenegotiat=="A deal was made"
replace f1_external2=0 if f1_external2==. & whatwastheoutcomeofthesenegotiat~=""
replace f1_external2=0 if f1_external2==. & f1_operate==0
replace f1_external2=0 if f1_external2==. & f1_step4==0
label var f1_external2 "Made deal with outside investor"
gen f1_external3=1 if howmuchnewinvestmentdidyoureceiv>=25000 & howmuchnewinvestmentdidyoureceiv~=.
replace f1_external3=0 if howmuchnewinvestmentdidyoureceiv<25000
replace f1_external3=0 if f1_external3==. & f1_external2==0
replace f1_external3=0 if f1_external3==. & f1_operate==0
replace f1_external3=1 if pleasealsoindicatethenewinve~="" & howmuchnewinvestmentdidyoureceiv==.
label var f1_external3 "Received at least 25000"
gen f1_external4=0 if f1_external3==0
replace f1_external4=howmuchnewinvestmentdidyoureceiv if howmuchnewinvestmentdidyoureceiv~=.
replace f1_external4=175000 if pleasealsoindicatethenewinve=="100,000 - 249,999 Euros" & f1_external4==.
replace f1_external4=32500 if pleasealsoindicatethenewinve=="25,000 - 49,999 Euros" & f1_external4==.
replace f1_external4=75000 if pleasealsoindicatethenewinve=="50,000 - 99,999 Euros" & f1_external4==.
label var f1_external4 "Amount new investment received"
gen f1_external5=source_incubaccel
replace f1_external5=0 if f1_external5==. & f1_operate==0
label var f1_external5 "Received Incubator grant"
* note: since external 4 (amount received) not asked in follow-up 2, don't include in index in order to allow comparability across rounds
foreach var of varlist f1_external1 f1_external2 f1_external3  f1_external5 {
  sum `var' 
  local thismean = r(mean) 
  local thissd = r(sd) 
  di "`thismean'" 
  di "`thissd'" 
  cap drop z1_`var'
  gen z1_`var' = (`var'-`thismean')/(`thissd') 
  } 
egen f1_externalindex=rowmean(z1_f1_external1 z1_f1_external2 z1_f1_external3  z1_f1_external5)
label var f1_externalindex "Aggregate Index of externals to external finance"
replace f1_externalindex=. if  f1_external2==. 

***************************************************************************
************ Measures from Second Follow-up Survey ************************
***************************************************************************

****** Different measures of survey completion *****************
* Completed full survey
gen fu2_follow1=surveystatus=="COMPLETE"|surveystatus=="COMPLETE & EXPRESS"
label var fu2_follow1 "Did full final round follow-up survey"

* Did at least part of the follow-up survey or express survey
gen fu2_follow2=fu2_follow1
replace fu2_follow2=1 if surveystatus=="EXPRESS"|surveystatus=="INCOMPLETE"|surveystatus=="INCOMPLETE & EXPRESS"
label var fu2_follow2 "Answered at least part of final follow-up survey"

**** DOMAIN 1: BUSINESS IS OPERATING ********************************************************
******* Business is operating or not *****************************
gen op1=substr(operatingstatus, 1, 1)
tab op1
gen fu2_operate=1 if op1=="1"|op1=="2"|op1=="3"|op1=="4"|op1=="y"
replace fu2_operate=0 if op1=="5"|op1=="6"|op1=="n"
* code standby/hiatus as not currently operating
replace fu2_operate=1 if fu2_operate==. & (firmid==338|firmid==160|firmid==118|firmid==349|firmid==296|firmid==306|firmid==101|firmid==25|firmid==152|firmid==137)
replace fu2_operate=0 if fu2_operate==. & (firmid==35|firmid==13|firmid==311|firmid==124|firmid==64|firmid==222|firmid==182|firmid==112|firmid==59)
* two firms with current status unknown, but that were closed at last follow-up, are assumed to be closed
replace fu2_operate=0 if firmid==305|firmid==331
label var fu2_operate "Operating at time of final follow-up"

**** DOMAIN 2: INVESTMENT READINESS ***********************************************************************
*** 2A: WILLINGNESS AND INTEREST IN TAKING ON EQUITY INVESTMENT *****************************************
* Interested in equity financing for the business
gen fu2_f1_interest1=cond(interestednewequity=="1) yes"|interestednewequity=="yes",1,0) if interestednewequity~=""
label var fu2_f1_interest1 "FU2: Interested in receiving equity investment"

* Maximum equity share willing to have held by outside investors
gen maxeq1=substr(maxequityshareoutside,1,2)
destring maxeq1, force replace
gen maxeq2=substr(maxequityshareoutside,1, 3)
destring maxeq2, force replace
gen maxeq3=maxequityshareoutside,
destring maxeq3, force replace
gen fu2_f1_interest2=maxeq3
replace fu2_f1_interest2=maxeq1 if maxeq1~=.
replace fu2_f1_interest2=maxeq2 if maxeq2~=.
replace fu2_f1_interest2=0 if maxequityshareoutside=="0%"
replace fu2_f1_interest2=29 if maxequityshareoutside=="<30%"
* maximum equity would sell is 100% for those who have sold whole firm
replace fu2_f1_interest2=100 if op1=="3"|op1=="4"|op1=="5"
* maximum equity is current equity if not interested in any more
tab outsideequityshare if fu2_f1_interest2==. & fu2_f1_interest1==0
replace fu2_f1_interest2=0 if fu2_f1_interest2==. & fu2_f1_interest1==0
label var fu2_f1_interest2 "FU2: Maximum share of equity would sell"

* Have specific deal terms to offer to outside investors
gen hdterms=substr(havedealterms,1,3)
gen fu2_f1_interest3=cond(havedealterms=="1) yes"|hdterms=="Yes"|hdterms=="yes",1,0) if havedealterms~=""
* no deal terms if missing and no interest in outside investors
replace fu2_f1_interest3=0 if fu2_f1_interest3==. & fu2_f1_interest1==0
label var fu2_f1_interest3 "FU2: Has specific deal terms to offer investor"

* Would consider a royalty-based investment
gen fu2_f1_interest4=cond(wouldconsiderroyalty=="1) yes"|wouldconsiderroyalty=="yes",1,0) if wouldconsiderroyalty~=""
* would not if missing and no interest in outside investors
replace fu2_f1_interest4=0 if fu2_f1_interest4==. & fu2_f1_interest1==0
label var fu2_f1_interest4 "FU2: Would consider royalties"

* replace missing variables as zero for firms closed down 
foreach var of varlist fu2_f1_interest1 fu2_f1_interest2 fu2_f1_interest3 fu2_f1_interest4 {
replace `var'=0 if fu2_operate==0
}

*** Get z-scores and average
foreach var of varlist fu2_f1_interest1 fu2_f1_interest2 fu2_f1_interest3 fu2_f1_interest4   {
  sum `var' 
  local thismean = r(mean) 
  local thissd = r(sd) 
  di "`thismean'" 
  di "`thissd'" 
  cap drop z1_`var'
  gen z1_`var' = (`var'-`thismean')/(`thissd') 
  } 
egen fu2_f1_interestindex=rowmean(z1_fu2_f1_interest1 z1_fu2_f1_interest2 z1_fu2_f1_interest3 z1_fu2_f1_interest4)
label var fu2_f1_interestindex "FU2: Aggregate Index of Willingness and Interest in Equity"
replace fu2_f1_interestindex=. if fu2_f1_interest1==.

*** 2B: GENERAL INVESTABILITY *****************************************
* Number of employees in company
gen fu2_f1_general1=employees
replace fu2_f1_general1=0 if fu2_operate==0 & fu2_f1_general1==.
sum fu2_f1_general1, de
* winsorize at the 99th percentile
replace fu2_f1_general1=r(p99) if fu2_f1_general1>r(p99) & fu2_f1_general1~=.
label var fu2_f1_general1 "FU2: Number of Employees"

* Founders work full-time
gen wft=substr(workfulltime,1,1)
gen fu2_f1_general2=cond(wft=="1"|wft=="2"|wft=="3"|wft=="4",1,0) if wft~=""
replace fu2_f1_general2=0 if fu2_operate==0 
label var fu2_f1_general2 "FU2: Founders work full-time in business"

* Positive total sales for first quarter of 2017
gen fu2_f1_general3=cond(totalsales>0,1,0) if totalsales~=.
gen sra=substr(salesrange,1,1)
* don't know if 0 is included in lower sales range, so only replace missings with other ranges
replace fu2_f1_general3=1 if (sra=="2"|sra=="3"|sra=="4"|sra=="5") & fu2_f1_general3==.
* closed firms with missing sales have 0 sales
replace fu2_f1_general3=0 if fu2_operate==0 & fu2_f1_general3==.
label var fu2_f1_general3 "FU2: Has positive revenue"

* Total sales for first quarter of 2017 of at least 10,000 euros
gen fu2_f1_general4=0 if fu2_f1_general3==0
replace fu2_f1_general4=1 if totalsales>=10000 & totalsales~=.
replace fu2_f1_general4=0 if totalsales<10000
replace fu2_f1_general4=0 if sra=="1" & fu2_f1_general4==.
replace fu2_f1_general4=1 if (sra=="2"|sra=="3"|sra=="4"|sra=="5") & fu2_f1_general4==.
replace fu2_f1_general4=0 if fu2_operate==0 & fu2_f1_general4==.
label var fu2_f1_general4 "FU2: Has revenues of at least 10,000 Euros"

* Business made positive profit in 2016
gen fu2_f1_general5=1 if totalprofits2016>0 & totalprofits2016~=.
replace fu2_f1_general5=0 if totalprofits2016<=0
gen pra=substr(profitsrange, 1, 1)
replace fu2_f1_general5=0 if (pra=="-"|pra=="0") & fu2_f1_general5==.
replace fu2_f1_general5=1 if (pra=="1"|pra=="2"|pra=="3"|pra=="4"|pra=="5"|pra=="6"|pra=="7"|pra=="8") & fu2_f1_general5==.
replace fu2_f1_general5=0 if fu2_operate==0 & fu2_f1_general5==.
replace fu2_f1_general5=1 if e_positiveprofit2016=="yes"
replace fu2_f1_general5=0 if e_positiveprofit2016=="no"
label var fu2_f1_general5 "FU2: Made a positive profit"

* Sales made in Western Europe or US
gen fu2_f1_general6=1 if (sold_eu~=""|sold_us~=""|e_salesUSorEU=="yes")
replace fu2_f1_general6=0 if fu2_f1_general6==. & (sold_croatia~=""|sold_kosovo~=""|sold_macedonia~=""|sold_montenegro~=""|sold_serbia~=""|sold_otherbalkan~=""|sold_unknown~=""|sold_othermarket~="")
replace fu2_f1_general6=0 if e_salesUSorEU=="no"
* no sales if no product ready for use
replace fu2_f1_general6=0 if productreadyforuse=="2) no" & fu2_f1_general6==.
* no sales if no sales at all made
replace fu2_f1_general6=0 if fu2_f1_general6==. & fu2_f1_general3==0
* no sales if closed
replace fu2_f1_general6=0 if fu2_f1_general6==. & fu2_operate==0
label var fu2_f1_general6 "FU2: Made sales to Western Europe or US"

*** Get z-scores and average
foreach var of varlist fu2_f1_general1 fu2_f1_general2 fu2_f1_general3 fu2_f1_general4 fu2_f1_general5 fu2_f1_general6  {
  sum `var' 
  local thismean = r(mean) 
  local thissd = r(sd) 
  di "`thismean'" 
  di "`thissd'" 
  cap drop z1_`var'
  gen z1_`var' = (`var'-`thismean')/(`thissd') 
  } 
egen fu2_f1_generalindex=rowmean(z1_fu2_f1_general1 z1_fu2_f1_general2 z1_fu2_f1_general3 z1_fu2_f1_general4 z1_fu2_f1_general5 z1_fu2_f1_general6)
label var fu2_f1_generalindex "FU2: Aggregate Index of General Investability"
replace fu2_f1_generalindex=. if fu2_f1_general2==. & fu2_f1_general3==. & fu2_f1_general4==.


*** 2C: MEETING THE SPECIFIC NEEDS OF INVESTORS *****************************************
* accounts of the business separated from those of the owners
gen fu2_f1_specific1=cond(accountseparate=="1) yes",1,0) if accountseparate~=""
replace fu2_f1_specific1=0 if fu2_operate==0
label var fu2_f1_specific1 "FU2: Separate business and personal accounts"

* revenue projection for the next 12 months made
gen fu2_f1_specific2=cond(haverevenueprojection=="1) yes", 1, 0) if haverevenueprojection~=""
replace fu2_f1_specific2=0 if fu2_operate==0
label var fu2_f1_specific2 "FU2: Has revenue projection"

* business knows customer acquisition costs
gen fu2_f1_specific3=cond(knowcustomeracquisitioncost=="1) yes", 1, 0) if knowcustomeracquisitioncost~=""
replace fu2_f1_specific3=0 if fu2_operate==0
label var fu2_f1_specific3 "FU2: Knows customer acquisition cost"

* Number of key metrics tracked
foreach var of varlist track_newsletters-track_customerlifetime {
gen v_`var'=cond(`var'>0 & `var'~=.,1,0)
}
egen fu2_f1_specific4=rsum(v_track_newsletters-v_track_customerlifetime)
replace fu2_f1_specific4=. if fu2_follow1==0 & fu2_operate==1 & fu2_f1_specific4==0
replace fu2_f1_specific4=. if fu2_operate==.
label var fu2_f1_specific4 "FU2: Number of key metrics tracked"

* Found out if product or service can be covered by IP
gen fu2_f1_specific5=cond(foundoutifcanuseip=="1) yes", 1, 0) if foundoutifcanuseip~=""
replace fu2_f1_specific5=0 if fu2_operate==0 & fu2_f1_specific5==.
label var fu2_f1_specific5 "FU2: Found out intellectual property"

* Has at least one form of intellectual property protection
gen fu2_f1_specific6=1 if havecopyright=="1) yes"|havecopyright=="2) application pending"
replace fu2_f1_specific6=1 if havetrademark=="1) yes"|havetrademark=="2) application pending"
replace fu2_f1_specific6=1 if haveindustrial=="1) yes"|haveindustrial=="2) application pending"
replace fu2_f1_specific6=1 if havepatent=="1) yes"|havepatent=="2) application pending"
replace fu2_f1_specific6=1 if haveotherip=="1) yes"|haveotherip=="2) application pending"
replace fu2_f1_specific6=0 if fu2_f1_specific6==. & fu2_f1_specific5==0
replace fu2_f1_specific6=0 if fu2_f1_specific6==. & (havecopyright~=""|havetrademark~="")
replace fu2_f1_specific6=0 if fu2_f1_specific6==. & fu2_operate==.
label var fu2_f1_specific6 "FU2: Has IP protection"

*** Get z-scores and average
foreach var of varlist fu2_f1_specific1 fu2_f1_specific2 fu2_f1_specific3 fu2_f1_specific4 fu2_f1_specific5 fu2_f1_specific6  {
  sum `var' 
  local thismean = r(mean) 
  local thissd = r(sd) 
  di "`thismean'" 
  di "`thissd'" 
  cap drop z1_`var'
  gen z1_`var' = (`var'-`thismean')/(`thissd') 
  } 
egen fu2_f1_specificindex=rowmean(z1_fu2_f1_specific1 z1_fu2_f1_specific2 z1_fu2_f1_specific3 z1_fu2_f1_specific4 z1_fu2_f1_specific5 z1_fu2_f1_specific6)
label var fu2_f1_specificindex "Aggregate Index of specific Investability"

**** DOMAIN 3: STEPS TOWARDS RECEIVING EXTERNAL FUNDING AND FUNDING RECEIVED ***********************************************************************

*** 3A: Steps towards getting external financing
* have contacted outside investor in the past year
gen fu2_f1_step1=cond(contactoutsideinvestor=="1) yes",1, 0) if contactoutsideinvestor~=""
tab interestednewequity if contactoutsideinvestor==""
* those not interested in outside investors have not contacted them
replace fu2_f1_step1=0 if contactoutsideinvestor=="" & fu2_f1_interest1==0
replace fu2_f1_step1=0 if fu2_f1_step1==. & fu2_operate==0
label var fu2_f1_step1 "FU2: Contacted outside investor"

* made a pitch to an outside investor
gen fu2_f1_step2=cond(didoutsidepitch=="1) yes", 1, 0) if didoutsidepitch~=""
tab interestednewequity if didoutsidepitch==""
* those not interested in outside investors have not pitched to them
replace fu2_f1_step2=0 if didoutsidepitch=="" & fu2_f1_interest1==0
replace fu2_f1_step2=0 if fu2_f1_step2==. & fu2_operate==0
label var fu2_f1_step2 "FU2: made a pitch"

* have a mentor helping support them raise funding
gen fu2_f1_step3=cond(hadfundingmentor=="1) yes", 1, 0) if hadfundingmentor~=""
* didn't answer if wasn't seeking funding
replace fu2_f1_step3=0 if fu2_f1_step1==0 & fu2_f1_step2==0
replace fu2_f1_step3=0 if hadfundingmentor=="" & fu2_f1_interest1==0
replace fu2_f1_step3=0 if fu2_operate==0 & fu2_f1_step3==.
label var fu2_f1_step3 "Has mentor helping"

* entered into negotiations with an outside investor
gen fu2_f1_step4=cond(enteredfundingnegotiations=="1) yes", 1, 0) if enteredfundingnegotiations~=""
* businesses sold have had negotiations
replace fu2_f1_step4=1 if op1=="3"|op1=="4"|op1=="5"
* firms that received equity and are on short or express surveys also entered negotiations
replace fu2_f1_step4=1 if fu2_f1_step4==. & (e_madeadeal~=""|desk_receivedequity=="yes")
replace fu2_f1_step4=0 if fu2_f1_step4==. & fu2_operate==0
label var fu2_f1_step4 "FU2 Entered into negotiation"

foreach var of varlist fu2_f1_step1 fu2_f1_step2 fu2_f1_step3 fu2_f1_step4  {
  sum `var' 
  local thismean = r(mean) 
  local thissd = r(sd) 
  di "`thismean'" 
  di "`thissd'" 
  cap drop z1_`var'
  gen z1_`var' = (`var'-`thismean')/(`thissd') 
  } 
egen fu2_f1_stepindex=rowmean(z1_fu2_f1_step1 z1_fu2_f1_step2 z1_fu2_f1_step3 z1_fu2_f1_step4)
label var fu2_f1_stepindex "Aggregate Index of steps to external finance"
replace fu2_f1_stepindex=. if fu2_f1_step1==. & fu2_f1_step2==. & fu2_f1_step3==.


*** 3B: External Financing Received
* Taken on new debt since August 2015
gen fu2_f1_external1=0 if currentdebt=="2) no"
replace fu2_f1_external1=1 if loan_familyfriends=="yes, new since August 2015"|creditcarddebt=="yes, new since August 2015"|loan_personalfinance=="yes, new since August 2015"|loan_businessbank=="yes, new since August 2015"
replace fu2_f1_external1=0 if currentdebt=="1) yes" & fu2_f1_external1==.
replace fu2_f1_external1=1 if amount_newdebt>0 & amount_newdebt~=.
replace fu2_f1_external1=0 if fu2_f1_external1==. & fu2_operate==0
replace fu2_f1_external1=1 if e_takennewdebt~=""
label var fu2_f1_external1 "FU2: Taken on new debt"

* Made a deal with an outside investor who is not family/friends ************************
gen fu2_f1_external2=1 if (ndeals_otherowner~="")|(ndeals_angel~="")|(ndeals_crowdfund~="")|(ndeals_accelerator~="")|(ndeals_vcfund~="")|(ndeals_govtfund~="")
replace fu2_f1_external2=0 if enteredfundingnegotiations~="" & fu2_f1_external2==.
replace fu2_f1_external2=1 if e_madeadeal~="" & fu2_f1_external2==.
replace fu2_f1_external2=0 if fu2_f1_external2==. & e_madeadeal=="" & (surveystatus=="EXPRESS"|surveystatus=="INCOMPLETE & EXPRESS")
replace fu2_f1_external2=1 if fu2_f1_external2==. & desk_receivedequity=="yes"
replace fu2_f1_external2=0 if fu2_f1_external2==. & desk_receivedequity=="no"
* firms that reported have made a deal in previous round
replace fu2_f1_external2=1 if firmid==33|firmid==330
* firms that did not report deal in previous round and are now closed have no deal
replace fu2_f1_external2=0 if fu2_f1_external2==. & fu2_operate==0 & (firmid~=283 & firmid~=316)
* code firms that sold entire firm to investors as having made equity deal (sold for 100% equity)
replace fu2_f1_external2=1 if op1=="3"|op1=="4"|op1=="5"
label var fu2_f1_external2 "Made a deal with an outside investor by final follow-up"

* Received at least 25,000 euros in outside investment since August 2015
gen fu2_f1_external3=0 if fu2_f1_external2==0
gen ir1=substr(investmentrange_otherowner,1,1)
destring ir1, force replace
gen ir2=substr(investmentrange_angel,1,1)
destring ir2, force replace
gen ir3=substr(investmentrange_crowdfund,1,1)
destring ir3, force replace
gen ir4=substr(investmentrange_accel, 1, 1)
destring ir4, force replace
gen ir5=substr(investmentrange_vc, 1, 1)
destring ir5, force replace
gen ir6=substr(investmentrange_govtfund, 1, 1)
destring ir6, force replace
replace fu2_f1_external3=1 if (ir1>=3 & ir1~=.)|(ir2>=3 & ir2~=.)|(ir3>=3 & ir3~=.)|(ir4>=3 & ir4~=.)|(ir5>=3 & ir5~=.)|(ir6>=3 & ir6~=.)
replace fu2_f1_external3=1 if  e_receivedatleast25000~=""
replace fu2_f1_external3=0 if fu2_f1_external2==1 & (ir1<=2|ir2<=2|ir3<=2|ir4<=2|ir5<=2|ir6<=2) & fu2_f1_external3==.
label var fu2_f1_external3 "FU2: Received at least 25000"

* Total amount of outside investment received not asked in this round (only range questions)
* for descriptive purposes, look at whether got 100,000 euros +
gen fu2_got100K=0 if fu2_f1_external3==0
replace fu2_got100K=1 if (ir1>=5 & ir1~=.)|(ir2>=5 & ir2~=.)|(ir3>=5 & ir3~=.)|(ir4>=5 & ir4~=.)|(ir5>=5 & ir5~=.)|(ir6>=5 & ir6~=.) 
replace fu2_got100K=0 if fu2_got100K==. & fu2_f1_external2==1 & (ir1<=4|ir2<=4|ir3<=4|ir4<=4|ir5<=4|ir6<=4) & fu2_got100K==.

* Received incubator or accelerator grant since august 2013
gen fu2_f1_external5=cond(receive_incubatoraccelerator=="1) yes", 1, 0) if receive_incubatoraccelerator~=""
replace fu2_f1_external5=1 if e_acceptedaccelerator~=""
replace fu2_f1_external5=0 if fu2_f1_external5==. & fu2_operate==0
label var fu2_f1_external5 "Received Incubator grant"

foreach var of varlist fu2_f1_external1 fu2_f1_external2 fu2_f1_external3 fu2_f1_external5 {
  sum `var' 
  local thismean = r(mean) 
  local thissd = r(sd) 
  di "`thismean'" 
  di "`thissd'" 
  cap drop z1_`var'
  gen z1_`var' = (`var'-`thismean')/(`thissd') 
  } 
egen fu2_f1_externalindex=rowmean(z1_fu2_f1_external1 z1_fu2_f1_external2 z1_fu2_f1_external3  z1_fu2_f1_external5)
label var fu2_f1_externalindex "Aggregate Index of externals to external finance"
replace fu2_f1_externalindex=. if  fu2_f1_external2==. 

****************** Attrition: Have information on business operating and whether have equity investment **************************
gen fu2_follow3=fu2_operate~=. & fu2_f1_external2~=.
label var fu2_follow3 "have information on whether firm open, and whether taken equity"

**** Data on types of external investment received ****
gen fu2_soldfirm=cond(op1=="3"|op1=="4"|op1=="5", 1, 0)
gen fu2_deal_otherowner=cond(ndeals_otherowner~="",1,0)
gen fu2_deal_angel=cond(ndeals_angel~="",1,0)
gen fu2_deal_crowdfund=cond(ndeals_crowdfund~="",1,0)
gen fu2_deal_accelerator=cond(ndeals_accelerator~="",1,0)
gen fu2_deal_vcfund=cond(ndeals_vcfund~="",1,0)
gen fu2_deal_govtfund=cond(ndeals_govtfund~="",1,0)
foreach var of varlist fu2_soldfirm-fu2_deal_govtfund {
replace `var'=. if fu2_follow1~=1
}
* and types of deals made
gen fu2_equityshare=0 if fu2_follow1==1
gen fu2_licensedeal=0 if fu2_follow1==1
gen fu2_royaltydeal=0 if fu2_follow1==1
gen fu2_convertiblenote=0 if fu2_follow1==1
gen fu2_otherdeal=0 if fu2_follow1==1
foreach var of varlist  receipt_otherowner receipt_angel receipt_crowdfund receipt_accelerator receipt_vcfund receipt_govtfund  {
replace fu2_equityshare=1 if `var'=="1) Equity share in business"|((op1=="3"|op1=="4"|op1=="5") & fu2_follow1==1)
replace fu2_licensedeal=1 if `var'=="2) Right to license product"
replace fu2_royaltydeal=1 if `var'=="3) Right to royalties"
replace fu2_convertiblenote=1 if `var'=="4) Convertible note"
replace fu2_otherdeal=1 if `var'=="5) other (please specify)"
}

* main challenge faced in business
gen fu2_mainchallenge=mainchallenge
* importance of financing 
gen fu2_challenge_gettingfinancing=challenge_gettingfinancing

*************************************************************
*********** MEDIA OUTCOME ***********************************
*************************************************************

* Meltwater media mentions data
gen baseanymedia=cond(totalnumber>0,1,0) if totalnumber~=.
gen anymedia=cond(m1_totalnumber>0,1,0) if m1_totalnumber~=. 
* baseline number of media articles
sum totalnumber, de
gen totalnumber_trim=totalnumber
replace totalnumber_trim=r(p99) if totalnumber>r(p99)
sum m1_totalnumber, de
gen m1_totalnumber_trim=m1_totalnumber
replace m1_totalnumber_trim=r(p99) if m1_totalnumber>r(p99)
* 2017 data
gen anymedia2017=cond(m2_totalnumber>0,1,0) if m2_totalnumber~=.
sum m2_totalnumber, de
gen m2_totalnumber_trim=m2_totalnumber
replace m2_totalnumber_trim=r(p99) if m2_totalnumber>r(p99)
* mentioned at all in either year
gen anyatall=anymedia
replace anyatall=1 if anyatall==0 & anymedia2017==1
gen totalnumber_total=m1_totalnumber_trim+m2_totalnumber_trim

* social media data
gen hasfacebook2016=cond(Facebook2016>0 & Facebook2016~=.,1,0) 
gen hastwitter2016=cond(Twitter2016>0 & Twitter2016~=.,1,0) 
gen hasalexarank2016=cond(AlexaGlobalRank2016~="",1,0)
gen hassimilarrank2016=cond(SimilarWebTotalRanking2016~="",1,0)
gen b_hasfacebook2016=cond(Facebook2015>0 & Facebook2015~=.,1,0)
gen b_hastwitter2016=cond(Twitter2015>0 & Twitter2015~=.,1,0)
gen b_hasalexarank2016=cond(AlexaGlobalRank2015~="",1,0)
gen b_hassimilarrank2016=cond(SimilarWebTotalRanking2015~="",1,0)
gen b_AngelList2016=AngelList2015
gen b_Facebook2016=Facebook2015
gen b_Twitter2016=Facebook2015
replace Facebook2016=0 if Facebook2016==.
replace b_Facebook2016=0 if b_Facebook2016==.
replace Twitter2016=0 if Twitter2016==.
replace b_Twitter2016=0 if b_Twitter2016==.
sum Facebook2016, de
gen Facebooktrim=Facebook2016
replace Facebooktrim=r(p95) if Facebook2016>r(p95) & Facebook2016~=.
gen twitter2016_trim=Twitter2016
sum Twitter2016, de
replace twitter2016_trim=r(p95) if Twitter2016>r(p95) & Twitter2016~=.
replace Facebooktrim=0 if Facebook2016==0
replace twitter2016_trim=0 if Twitter2016==0

*** 2017 Social Media outcomes *****
gen hasfacebook2017=cond(facebook2017>0 & facebook2017~=.,1,0) 
gen hastwitter2017=cond(twitter2017>0 & twitter2017~=.,1,0) 
gen hasalexarank2017=cond(alexaglobalrank2017~="",1,0)
gen hassimilarrank2017=cond(similarwebtotalranking2017~="",1,0)
gen b_hasfacebook2017=cond(Facebook2015>0 & Facebook2015~=.,1,0)
gen b_hastwitter2017=cond(Twitter2015>0 & Twitter2015~=.,1,0)
gen b_hasalexarank2017=cond(AlexaGlobalRank2015~="",1,0)
gen b_hassimilarrank2017=cond(SimilarWebTotalRanking2015~="",1,0)
gen b_angellist2017=AngelList2015
gen b_facebook2017=Facebook2015
gen b_twitter2017=Facebook2015
replace facebook2017=0 if facebook2017==.
replace b_facebook2017=0 if b_facebook2017==.
replace twitter2017=0 if twitter2017==.
replace b_twitter2017=0 if b_twitter2017==.
sum facebook2017, de
gen facebooktrim=facebook2017
replace facebooktrim=r(p95) if facebook2017>r(p95) & facebook2017~=.
gen twitter2017_trim=twitter2017
sum twitter2017, de
replace twitter2017_trim=r(p95) if twitter2017>r(p95) & twitter2017~=.
replace facebooktrim=0 if facebook2017==0
replace twitter2017_trim=0 if twitter2017==0


* Media Buzz Index
foreach var of varlist anymedia m1_totalnumber_trim Facebooktrim twitter2016_trim {
  sum `var' 
  local thismean = r(mean) 
  local thissd = r(sd) 
  di "`thismean'" 
  di "`thissd'" 
  cap drop z1_`var'
  gen z1_`var' = (`var'-`thismean')/(`thissd') 
  } 
egen mediabuzz2016=rowmean(z1_anymedia z1_m1_totalnumber_trim z1_Facebooktrim z1_twitter2016_trim)
label var mediabuzz2016 "Media buzz 2016"

foreach var of varlist anymedia2017 m2_totalnumber_trim facebooktrim twitter2017_trim {
  sum `var' 
  local thismean = r(mean) 
  local thissd = r(sd) 
  di "`thismean'" 
  di "`thissd'" 
  cap drop z1_`var'
  gen z1_`var' = (`var'-`thismean')/(`thissd') 
  } 
egen mediabuzz2017=rowmean(z1_anymedia z1_m2_totalnumber_trim z1_facebooktrim z1_twitter2017_trim)
label var mediabuzz2017 "Media buzz 2017"

gen b_anymedia=baseanymedia
gen b_anymedia2017=baseanymedia
gen b_m1_totalnumber_trim=totalnumber_trim
gen b_m2_totalnumber_trim=totalnumber_trim
gen Facebook2015trim=Facebook2015
replace Facebook2015trim=0 if Facebook2015==0|Facebook2015==.
sum Facebook2015, de
replace Facebook2015trim=r(p95) if Facebook2015>r(p95) & Facebook2015~=.
gen b_Facebooktrim=Facebook2015trim
gen b_facebooktrim=Facebook2015trim
gen Twitter2015trim=Twitter2015
replace Twitter2015trim=0 if Twitter2015==0|Twitter2015==.
sum Twitter2015, de
replace Twitter2015trim=r(p95) if Twitter2015>r(p95) & Twitter2015~=.
gen b_twitter2016_trim=Twitter2015trim
gen b_twitter2017_trim=Twitter2015trim
foreach var of varlist b_anymedia b_m2_totalnumber_trim b_facebooktrim b_twitter2017_trim {
  sum `var' 
  local thismean = r(mean) 
  local thissd = r(sd) 
  di "`thismean'" 
  di "`thissd'" 
  cap drop z1_`var'
  gen z1_`var' = (`var'-`thismean')/(`thissd') 
  } 
egen b_mediabuzz2017=rowmean(z1_b_anymedia z1_b_m2_totalnumber_trim z1_b_facebooktrim z1_b_twitter2017_trim)
label var b_mediabuzz2017 "Baseline Media buzz"
gen b_mediabuzz2016=b_mediabuzz2017


sort firmid

* Save master dataset
save "IRMasterData.dta", replace
